@@ -167,11 +167,11 @@ class TargetSurface():
         return
 
     def move(
-        self, 
-        _add=(1, 1), 
-        rel=True, 
-        use_func=False):
-        
+            self,
+            _add=(1, 1),
+            rel=True,
+            use_func=False):
+
         if use_func:
             self.dest = self.calc_dest(_add)
         elif rel:
@@ -319,10 +319,11 @@ class TargetsManager():
         _targets = self.get_targets(self.shtbase.difficulty_index)
         self.set_target_count(len(_targets))
 
-        return [
-            TargetSurface(self.shtbase, self, t[0:-1], t[-1])
-            for t in _targets
-        ]
+        return \
+            [
+                TargetSurface(self.shtbase, self, t[0:-1], t[-1])
+                for t in _targets
+            ]
 
     def set_surfaces(self):
         self.surfaces = self.get_target_surfaces()
@@ -395,19 +396,20 @@ class TargetsManager():
 
 class InputSurface():
     def __init__(
-            self,
-            shtbase,
-            font_lang_code=None,
-            font_bold=False,
-            border_radius=5,
-            border_width=1,
-            border_color=(200, 20, 30, 60)):
+        self,
+        shtbase,
+        font_lang_code=None,
+        font_bold=False,
+        border_radius=5,
+        border_width=1,
+        border_color=(200, 20, 30, 60)
+    ):
 
         self.shtbase = shtbase
         self.ps = self.shtbase.ps
         self.font_size = 55
-        self.font_lang_code = font_lang_code or \
-            self.shtbase.font_lang_code
+        self.font_lang_code = \
+            font_lang_code or self.shtbase.font_lang_code
         self.font = \
             get_sys_font_by_lang_code(self.font_lang_code) \
             if self.font_lang_code else \
@@ -424,6 +426,9 @@ class InputSurface():
 
         self.font.set_bold(self.font_bold)
 
+    def set_rect(self, rect=None):
+        self.update_rect(rect)
+
     def update_rect(self, rect=None):
         self.w, self.h = self.rect = rect or self.surface.get_size()
 
@@ -432,9 +437,20 @@ class InputSurface():
             self.shtbase.w_width_of_2 - self.w / 2,
             self.shtbase.w_height - self.h)
 
-    def _update(self):
+    def get_input(self, strip=True):
+        _input = self.shtbase._input
+        if strip:
+            return _input.strip()
+        else:
+            return _input
+
+    def set_input(self, input_str):
+        self.shtbase._input = input_str
+
+    def _update(self, _input=None):
+        _input = _input or self.get_input()
         self.surface = self.font.render(
-            self.shtbase._input.strip(),
+            _input,
             False, self.font_color)
 
     def _blit(self):
@@ -532,7 +548,9 @@ class DefenseSurface():
 
 
 class InfoSurface():
-    def __init__(self, shtbase):
+    def __init__(
+            self,
+            shtbase):
         self.shtbase = shtbase
         self.ps = shtbase.ps
         self.surface = self.ps.surface
@@ -543,32 +561,11 @@ class InfoSurface():
         self.font_size = 25
         self.font = get_default_font(self.font_size)
 
-        self.score_font_size = 55
-        self.score_font = get_default_font(self.score_font_size)
-
-        self.datetime_diff_font_size = 50
-        self.datetime_diff_font = get_default_font(
-            self.datetime_diff_font_size)
-        self.datetime_diff_font_color = ...
-
         self.font = get_default_font(self.font_size)
 
         self.game_info_surface = self.font.render(
             self.game_info, False, self.game_info_color)
 
-        self.score = 0
-        self._pass = False
-        self.ps_info_surface = ...
-
-        self.score_surface = ...
-        self.datetime_diff_surface = ...
-        self.greeting_surface = ...
-
-        self.end_time = self.ps.end_time = None
-
-    def get_score_font_color(self):
-        return (20, 255, 0) if self._pass else (255, 20, 0)
-
     def get_win_info(self):
         return \
             '|' + _('win: ') + str(self.shtbase.win_count) + \
@@ -580,6 +577,39 @@ class InfoSurface():
         _w, _ = self.win_info_surface.get_size()
         return [self.ps.w_width - _w, 0]
 
+    def blit(self):
+        self.win_info_surface = self.font.render(
+            self.get_win_info(), False, self.game_info_color)
+
+        self.surface.blit(self.game_info_surface, self.game_info_dest)
+        self.surface.blit(self.win_info_surface, self.get_win_info_dest())
+
+
+class ScoreSurface(InfoSurface):
+    def __init__(
+            self,
+            shtbase):
+        self.shtbase = shtbase
+        self.ps = shtbase.ps
+        self.surface = self.ps.surface
+        self.score = 0
+        self._pass = False
+        self.score_font_size = 55
+        self.score_font = get_default_font(self.score_font_size)
+
+        self.datetime_diff_font_size = 50
+        self.datetime_diff_font = get_default_font(
+            self.datetime_diff_font_size)
+        self.datetime_diff_font_color = None
+
+        self.score_surface = None
+        self.datetime_diff_surface = None
+        self.greeting_surface = None
+        self.end_time = self.ps.end_time = None
+
+    def get_score_font_color(self):
+        return (20, 255, 0) if self._pass else (255, 20, 0)
+
     def get_datetime_diff_str(self):
         if self.end_time is None:
             self.end_time = self.ps.end_time = datetime.now()
@@ -589,13 +619,6 @@ class InfoSurface():
         _min, _sec = divmod(_rem, 60)
         return _('Cost: ') + f'{_h}:{_min}:{_sec}'
 
-    def blit(self):
-        self.win_info_surface = self.font.render(
-            self.get_win_info(), False, self.game_info_color)
-
-        self.surface.blit(self.game_info_surface, self.game_info_dest)
-        self.surface.blit(self.win_info_surface, self.get_win_info_dest())
-
     def get_score(self):
         self.score = int(
             100 *
@@ -610,10 +633,10 @@ class InfoSurface():
     def get_greeting(self):
         _player_name = self.shtbase.get_player_name()
         return \
-        (
-            _('Success! Dear %s, you are so awesome!') if self._pass else \
-            _('Dear %s, practice makes perfect, keep trying!')
-        )%_player_name
+            (
+                _('Success! Dear %s, you are so awesome!') if self._pass else
+                _('Dear %s, practice makes perfect, keep trying!')
+            ) % _player_name
 
     def get_score_str(self):
         return _('Score: ') + str(self.score)
@@ -640,7 +663,7 @@ class InfoSurface():
             self.ps.w_height_of_2 + _h
         ]
 
-    def score_blit(self):
+    def blit(self):
         self.score = self.get_score()
         self.get_score_pass()
 
@@ -674,7 +697,11 @@ class InfoSurface():
 
 
 class ShootingBase(GameBase, PsKeyCode):
-    def __init__(self, ps, font_lang_code=None):
+    def __init__(
+        self,
+        ps,
+        font_lang_code=None
+    ):
         assert hasattr(self, 'name_t')
         assert hasattr(self, 'difficulties')
         assert hasattr(self, 'module_str')
@@ -709,6 +736,7 @@ class ShootingBase(GameBase, PsKeyCode):
         self.info_surface = self.get_info_surface()
         self.defense_surface = self.get_defense_surface()
         self.input_surface = self.get_input_surface()
+        self.score_surface = self.get_score_surface()
         self.copy_path = get_copy_path(self.module_str)
 
         self.last_timedelta = timedelta(0)
@@ -721,10 +749,20 @@ class ShootingBase(GameBase, PsKeyCode):
         self.target_count = 0
         self.print_game_info()
 
+    def set_score_surface(self, score_surface=None):
+        self.score_surface = score_surface or ScoreSurface(self)
+
+    def get_score_surface(self):
+        score_surface = \
+            hasattr(self, 'score_surface') and \
+            self.score_surface or \
+            ScoreSurface(self)
+        return score_surface
+
     def get_player_name(self):
         return self.player_name
-    
-    def set_player_name(self,name):
+
+    def set_player_name(self, name):
         self.player_name = self.ps.player_name = name
 
     def set_input(self, content=''):
@@ -756,26 +794,6 @@ class ShootingBase(GameBase, PsKeyCode):
     def key_clean(self, code):
         return 48 <= code <= 57 or code == 45
 
-    def handle_events(self, events):
-        for e in events:
-            if e.type == pygame.QUIT:
-                exit()
-            elif e.type == pygame.KEYDOWN:
-                if e.key == pygame.K_ESCAPE:
-                    self.save_menu._menu.enable()
-                    self.last_timedelta += datetime.now() - self.start_time
-                    self.save_menu._menu.mainloop(self.surface)
-                    self.start_time = datetime.now()
-                    return
-                elif e.key == pygame.K_BACKSPACE:
-                    self._input = self._input[0:-1]
-                    self.input_surface._update()
-                    return
-                elif self.key_clean(e.key):
-                    self._input += chr(e.key)
-                    self.input_surface._update()
-                    return
-
     def load(self):
         try:
             self._load = True
@@ -814,6 +832,26 @@ class ShootingBase(GameBase, PsKeyCode):
     def all_targets_gone(self):
         return self.win_count + self.lose_count < self.target_count
 
+    def handle_events(self, events):
+        for e in events:
+            if e.type == pygame.QUIT:
+                exit()
+            elif e.type == pygame.KEYDOWN:
+                if e.key == pygame.K_ESCAPE:
+                    self.save_menu._menu.enable()
+                    self.last_timedelta += datetime.now() - self.start_time
+                    self.save_menu._menu.mainloop(self.surface)
+                    self.start_time = datetime.now()
+                    return
+                elif e.key == pygame.K_BACKSPACE:
+                    self._input = self._input[0:-1]
+                    self.input_surface._update()
+                    return
+                elif self.key_clean(e.key):
+                    self._input += chr(e.key)
+                    self.input_surface._update()
+                    return
+
     def start(self):
 
         self._start()
@@ -837,6 +875,6 @@ class ShootingBase(GameBase, PsKeyCode):
                 self.targets_manager.blit()
                 self.input_surface.blit()
             else:
-                self.info_surface.score_blit()
+                self.score_surface.blit()
 
             pygame.display.update()
