@@ -20,6 +20,7 @@ from primaryschool.subjects import *
 from primaryschool.subjects._abc_ import GameBase
 from primaryschool.subjects._common_.shootingbase import *
 from primaryschool.subjects.yuwen.words import cn_ps_c, cn_ps_c_bb
+from primaryschool.subjects.yuwen.yumu import p_a, p_e, p_i, p_o, p_u, p_v
 
 # primaryschool.subjects.yuwen.g_pinyin_missile
 module_str = __name__
@@ -72,8 +73,56 @@ pinyin = Pinyin()
 cn_ps_chars = cn_ps_c_bb
 
 
+class PmInputSurface(InputSurface):
+    def __init__(
+        self,
+        shtbase,
+        font_lang_code=None,
+        font_bold=False,
+        border_radius=5,
+        border_width=1,
+        border_color=(200, 20, 30, 60)
+    ):
+        super().__init__(
+            shtbase,
+            font_lang_code,
+            font_bold,
+            border_radius,
+            border_width,
+            border_color
+        )
+        self.candidates = []
+        self.p_a = p_a
+        self.p_o = p_o
+        self.p_e = p_e
+        self.p_i = p_i
+        self.p_u = p_u
+        self.p_v = p_v
+        self.aoeiuv = [
+            self.p_a,
+            self.p_o,
+            self.p_e,
+            self.p_i,
+            self.p_u,
+            self.p_v
+        ]
+
+    def get_input(self):
+        _input = super().get_input()
+        _new_input = _input
+        for yms in self.aoeiuv:
+            if yms[0] in _input:
+                for i, _ym in enumerate(yms[1:]):
+                    _new_input += f'  ({i+1})' + _input.replace(yms[0], _ym)
+                break
+        return _input if _input == _new_input else '(0)' + _new_input
+
+
 class PmTargetsManager(TargetsManager):
-    def __init__(self, shtbase):
+    def __init__(
+        self,
+        shtbase
+    ):
         super().__init__(
             shtbase,
             target_surface_lang_code='zh_CN'
@@ -127,7 +176,10 @@ class PmTargetsManager(TargetsManager):
 
 
 class PinyinMissile(ShootingBase):
-    def __init__(self, ps):
+    def __init__(
+        self,
+        ps
+    ):
         self.name_t = name_t
         self.difficulties = difficulties
         self.module_str = module_str
@@ -136,6 +188,9 @@ class PinyinMissile(ShootingBase):
     def get_targets_manager(self):
         return PmTargetsManager(self)
 
+    def get_input_surface(self):
+        return PmInputSurface(self)
+
     def key_clean(self, code):
         return \
             self.keycode_in_pure_num(code) or \
